# Generated by Django 5.2.11 on 2026-02-05 15:42

import django.db.models.deletion
import django_lifecycle.mixins
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AsOfTestModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
            ],
            bases=(django_lifecycle.mixins.LifecycleModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='HistoryDeleteTestModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
            ],
            bases=(django_lifecycle.mixins.LifecycleModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='RobustnessTestModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
            ],
            bases=(django_lifecycle.mixins.LifecycleModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='ScenarioTestModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
            ],
            bases=(django_lifecycle.mixins.LifecycleModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='SchedTestModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
            ],
            bases=(django_lifecycle.mixins.LifecycleModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='TemporalTestModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
            ],
            bases=(django_lifecycle.mixins.LifecycleModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='TestBitemporalModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
            ],
            bases=(django_lifecycle.mixins.LifecycleModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='TimeCmdTestModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
            ],
            bases=(django_lifecycle.mixins.LifecycleModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='TraceModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
            ],
        ),
        migrations.CreateModel(
            name='HistoricalAsOfTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical as of test model',
                'verbose_name_plural': 'historical as of test models',
                'ordering': ('-valid_from', '-history_id'),
                'get_latest_by': ('valid_from', 'history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalHistoryDeleteTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical history delete test model',
                'verbose_name_plural': 'historical history delete test models',
                'ordering': ('-valid_from', '-history_id'),
                'get_latest_by': ('valid_from', 'history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalRobustnessTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical robustness test model',
                'verbose_name_plural': 'historical robustness test models',
                'ordering': ('-valid_from', '-history_id'),
                'get_latest_by': ('valid_from', 'history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalScenarioTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical scenario test model',
                'verbose_name_plural': 'historical scenario test models',
                'ordering': ('-valid_from', '-history_id'),
                'get_latest_by': ('valid_from', 'history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalSchedTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical sched test model',
                'verbose_name_plural': 'historical sched test models',
                'ordering': ('-valid_from', '-history_id'),
                'get_latest_by': ('valid_from', 'history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalTemporalTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical temporal test model',
                'verbose_name_plural': 'historical temporal test models',
                'ordering': ('-valid_from', '-history_id'),
                'get_latest_by': ('valid_from', 'history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalTestBitemporalModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical test bitemporal model',
                'verbose_name_plural': 'historical test bitemporal models',
                'ordering': ('-valid_from', '-history_id'),
                'get_latest_by': ('valid_from', 'history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalTimeCmdTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical time cmd test model',
                'verbose_name_plural': 'historical time cmd test models',
                'ordering': ('-valid_from', '-history_id'),
                'get_latest_by': ('valid_from', 'history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='HistoricalTraceModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical trace model',
                'verbose_name_plural': 'historical trace models',
                'ordering': ('-valid_from', '-history_id'),
                'get_latest_by': ('valid_from', 'history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='MetaHistoricalAsOfTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.IntegerField(blank=True, db_index=True)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('meta_history_id', models.AutoField(primary_key=True, serialize=False)),
                ('sys_from', models.DateTimeField(db_index=True)),
                ('sys_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this system record was superseded.', null=True)),
                ('meta_history_change_reason', models.CharField(max_length=100, null=True)),
                ('meta_history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('meta_task_name', models.CharField(blank=True, help_text='Name of the Celery PeriodicTask scheduled for this record.', max_length=255, null=True, unique=True)),
                ('meta_task_status', models.CharField(choices=[('NONE', 'None'), ('SCHEDULED', 'Scheduled'), ('DONE', 'Done'), ('CANCELLED', 'Cancelled')], default='NONE', max_length=20)),
                ('history_object', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to='lex_app.historicalasoftestmodel')),
                ('history_user', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('meta_history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical historical as of test model',
                'verbose_name_plural': 'historical historical as of test models',
                'db_table': 'lex_app_asoftestmodel_meta_history',
                'ordering': ('-sys_from', '-meta_history_id'),
                'get_latest_by': ('sys_from', 'meta_history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='MetaHistoricalHistoryDeleteTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.IntegerField(blank=True, db_index=True)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('meta_history_id', models.AutoField(primary_key=True, serialize=False)),
                ('sys_from', models.DateTimeField(db_index=True)),
                ('sys_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this system record was superseded.', null=True)),
                ('meta_history_change_reason', models.CharField(max_length=100, null=True)),
                ('meta_history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('meta_task_name', models.CharField(blank=True, help_text='Name of the Celery PeriodicTask scheduled for this record.', max_length=255, null=True, unique=True)),
                ('meta_task_status', models.CharField(choices=[('NONE', 'None'), ('SCHEDULED', 'Scheduled'), ('DONE', 'Done'), ('CANCELLED', 'Cancelled')], default='NONE', max_length=20)),
                ('history_object', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to='lex_app.historicalhistorydeletetestmodel')),
                ('history_user', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('meta_history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical historical history delete test model',
                'verbose_name_plural': 'historical historical history delete test models',
                'db_table': 'lex_app_historydeletetestmodel_meta_history',
                'ordering': ('-sys_from', '-meta_history_id'),
                'get_latest_by': ('sys_from', 'meta_history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='MetaHistoricalRobustnessTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.IntegerField(blank=True, db_index=True)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('meta_history_id', models.AutoField(primary_key=True, serialize=False)),
                ('sys_from', models.DateTimeField(db_index=True)),
                ('sys_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this system record was superseded.', null=True)),
                ('meta_history_change_reason', models.CharField(max_length=100, null=True)),
                ('meta_history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('meta_task_name', models.CharField(blank=True, help_text='Name of the Celery PeriodicTask scheduled for this record.', max_length=255, null=True, unique=True)),
                ('meta_task_status', models.CharField(choices=[('NONE', 'None'), ('SCHEDULED', 'Scheduled'), ('DONE', 'Done'), ('CANCELLED', 'Cancelled')], default='NONE', max_length=20)),
                ('history_object', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to='lex_app.historicalrobustnesstestmodel')),
                ('history_user', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('meta_history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical historical robustness test model',
                'verbose_name_plural': 'historical historical robustness test models',
                'db_table': 'lex_app_robustnesstestmodel_meta_history',
                'ordering': ('-sys_from', '-meta_history_id'),
                'get_latest_by': ('sys_from', 'meta_history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='MetaHistoricalScenarioTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.IntegerField(blank=True, db_index=True)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('meta_history_id', models.AutoField(primary_key=True, serialize=False)),
                ('sys_from', models.DateTimeField(db_index=True)),
                ('sys_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this system record was superseded.', null=True)),
                ('meta_history_change_reason', models.CharField(max_length=100, null=True)),
                ('meta_history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('meta_task_name', models.CharField(blank=True, help_text='Name of the Celery PeriodicTask scheduled for this record.', max_length=255, null=True, unique=True)),
                ('meta_task_status', models.CharField(choices=[('NONE', 'None'), ('SCHEDULED', 'Scheduled'), ('DONE', 'Done'), ('CANCELLED', 'Cancelled')], default='NONE', max_length=20)),
                ('history_object', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to='lex_app.historicalscenariotestmodel')),
                ('history_user', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('meta_history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical historical scenario test model',
                'verbose_name_plural': 'historical historical scenario test models',
                'db_table': 'lex_app_scenariotestmodel_meta_history',
                'ordering': ('-sys_from', '-meta_history_id'),
                'get_latest_by': ('sys_from', 'meta_history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='MetaHistoricalSchedTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.IntegerField(blank=True, db_index=True)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('meta_history_id', models.AutoField(primary_key=True, serialize=False)),
                ('sys_from', models.DateTimeField(db_index=True)),
                ('sys_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this system record was superseded.', null=True)),
                ('meta_history_change_reason', models.CharField(max_length=100, null=True)),
                ('meta_history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('meta_task_name', models.CharField(blank=True, help_text='Name of the Celery PeriodicTask scheduled for this record.', max_length=255, null=True, unique=True)),
                ('meta_task_status', models.CharField(choices=[('NONE', 'None'), ('SCHEDULED', 'Scheduled'), ('DONE', 'Done'), ('CANCELLED', 'Cancelled')], default='NONE', max_length=20)),
                ('history_object', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to='lex_app.historicalschedtestmodel')),
                ('history_user', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('meta_history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical historical sched test model',
                'verbose_name_plural': 'historical historical sched test models',
                'db_table': 'lex_app_schedtestmodel_meta_history',
                'ordering': ('-sys_from', '-meta_history_id'),
                'get_latest_by': ('sys_from', 'meta_history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='MetaHistoricalTemporalTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.IntegerField(blank=True, db_index=True)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('meta_history_id', models.AutoField(primary_key=True, serialize=False)),
                ('sys_from', models.DateTimeField(db_index=True)),
                ('sys_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this system record was superseded.', null=True)),
                ('meta_history_change_reason', models.CharField(max_length=100, null=True)),
                ('meta_history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('meta_task_name', models.CharField(blank=True, help_text='Name of the Celery PeriodicTask scheduled for this record.', max_length=255, null=True, unique=True)),
                ('meta_task_status', models.CharField(choices=[('NONE', 'None'), ('SCHEDULED', 'Scheduled'), ('DONE', 'Done'), ('CANCELLED', 'Cancelled')], default='NONE', max_length=20)),
                ('history_object', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to='lex_app.historicaltemporaltestmodel')),
                ('history_user', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('meta_history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical historical temporal test model',
                'verbose_name_plural': 'historical historical temporal test models',
                'db_table': 'lex_app_temporaltestmodel_meta_history',
                'ordering': ('-sys_from', '-meta_history_id'),
                'get_latest_by': ('sys_from', 'meta_history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='MetaHistoricalTestBitemporalModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.IntegerField(blank=True, db_index=True)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('meta_history_id', models.AutoField(primary_key=True, serialize=False)),
                ('sys_from', models.DateTimeField(db_index=True)),
                ('sys_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this system record was superseded.', null=True)),
                ('meta_history_change_reason', models.CharField(max_length=100, null=True)),
                ('meta_history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('meta_task_name', models.CharField(blank=True, help_text='Name of the Celery PeriodicTask scheduled for this record.', max_length=255, null=True, unique=True)),
                ('meta_task_status', models.CharField(choices=[('NONE', 'None'), ('SCHEDULED', 'Scheduled'), ('DONE', 'Done'), ('CANCELLED', 'Cancelled')], default='NONE', max_length=20)),
                ('history_object', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to='lex_app.historicaltestbitemporalmodel')),
                ('history_user', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('meta_history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical historical test bitemporal model',
                'verbose_name_plural': 'historical historical test bitemporal models',
                'db_table': 'lex_app_testbitemporalmodel_meta_history',
                'ordering': ('-sys_from', '-meta_history_id'),
                'get_latest_by': ('sys_from', 'meta_history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='MetaHistoricalTimeCmdTestModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('created_by', models.TextField(blank=True, editable=False, null=True)),
                ('edited_by', models.TextField(blank=True, editable=False, null=True)),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.IntegerField(blank=True, db_index=True)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('meta_history_id', models.AutoField(primary_key=True, serialize=False)),
                ('sys_from', models.DateTimeField(db_index=True)),
                ('sys_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this system record was superseded.', null=True)),
                ('meta_history_change_reason', models.CharField(max_length=100, null=True)),
                ('meta_history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('meta_task_name', models.CharField(blank=True, help_text='Name of the Celery PeriodicTask scheduled for this record.', max_length=255, null=True, unique=True)),
                ('meta_task_status', models.CharField(choices=[('NONE', 'None'), ('SCHEDULED', 'Scheduled'), ('DONE', 'Done'), ('CANCELLED', 'Cancelled')], default='NONE', max_length=20)),
                ('history_object', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to='lex_app.historicaltimecmdtestmodel')),
                ('history_user', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('meta_history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical historical time cmd test model',
                'verbose_name_plural': 'historical historical time cmd test models',
                'db_table': 'lex_app_timecmdtestmodel_meta_history',
                'ordering': ('-sys_from', '-meta_history_id'),
                'get_latest_by': ('sys_from', 'meta_history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name='MetaHistoricalTraceModel',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('history_id', models.IntegerField(blank=True, db_index=True)),
                ('valid_from', models.DateTimeField(db_index=True)),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('valid_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this fact ceased to be true in the real world.', null=True)),
                ('meta_history_id', models.AutoField(primary_key=True, serialize=False)),
                ('sys_from', models.DateTimeField(db_index=True)),
                ('sys_to', models.DateTimeField(blank=True, default=None, help_text='The date/time when this system record was superseded.', null=True)),
                ('meta_history_change_reason', models.CharField(max_length=100, null=True)),
                ('meta_history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('meta_task_name', models.CharField(blank=True, help_text='Name of the Celery PeriodicTask scheduled for this record.', max_length=255, null=True, unique=True)),
                ('meta_task_status', models.CharField(choices=[('NONE', 'None'), ('SCHEDULED', 'Scheduled'), ('DONE', 'Done'), ('CANCELLED', 'Cancelled')], default='NONE', max_length=20)),
                ('history_object', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to='lex_app.historicaltracemodel')),
                ('history_user', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('meta_history_user', models.ForeignKey(db_constraint=False, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical historical trace model',
                'verbose_name_plural': 'historical historical trace models',
                'db_table': 'lex_app_tracemodel_meta_history',
                'ordering': ('-sys_from', '-meta_history_id'),
                'get_latest_by': ('sys_from', 'meta_history_id'),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]
